***************************************************
Working with radial velocity data (`thejoker.data`)
***************************************************

.. currentmodule:: thejoker.data

Introduction
============

|thejoker| provides a class for storing and passing around radial velocity
measurements for individual targets.

TODO: note that default behavior is to subtract out minimum time, so phi0 will
be phase at minimum time.

API
===

.. automodapi:: thejoker.data
    :no-inheritance-diagram:
